@@ -1008,6 +1008,7 @@ umount /sys
 ##< Exec Auto Setup Mode >##
 ## Executing hwsetup-mol
 # check /etc/sysconfig/mol directory
+mount -t usbfs none /proc/bus/usb
 if [ -d /etc/sysconfig/mol ]
 then
 	for f in $(echo /etc/sysconfig/mol/*)
@@ -1030,6 +1031,7 @@ fi
 
 /exec/hwsetup-mol -p ${HWSETUP_OPT}
 [ -f /etc/sysconfig/mol/mol ] && . /etc/sysconfig/mol/mol
+umount /proc/bus/usb
 
 ## XkbLayout and Videocard
 if [ -z "${NOVIDEO}" -a -f /etc/X11/xorg.conf ]
